@@ -13,7 +13,9 @@ def is_dicom_file(file_path_or_obj):
             return False
         file_obj = open(file_obj, "rb")
     try:
-        return file_obj.read(132).decode('ASCII')[-4:] == 'DICM'
+        result = file_obj.read(132).decode('ASCII')[-4:] == 'DICM'
+        file_obj.seek(0)
+        return result
     except UnicodeDecodeError:
         return False
 
@@ -44,3 +46,11 @@ def get_pixels(p, normalize=False):
     if isinstance(normalize, list):
         return (pixels + np.min(pixels)) / (np.max(pixels) - np.min(pixels)) * normalize[1] + normalize[0]
     return pixels
+
+
+def is_compressed(p):
+    try:
+        p.convert_pixel_data()
+        return False
+    except NotImplementedError:
+        return True
